@@ -12,18 +12,29 @@ when 'Linux'
   when 'Gentoo'
     packagename = 'net-misc/ntp'
   end
+when 'AIX'
+  packagename = 'bos.net.tcp.client'
+when 'Solaris'
+  case fact('operatingsystemrelease')
+  when '5.10'
+    packagename = ['SUNWntpr','SUNWntpu']
+  when '5.11'
+    packagename = 'service/network/ntp'
+  end
 else
   packagename = 'ntp'
 end
 
-describe 'ntp::install class' do
+describe 'ntp::install class', :unless => UNSUPPORTED_PLATFORMS.include?(fact('osfamily')) do
   it 'installs the package' do
     apply_manifest(%{
       class { 'ntp': }
     }, :catch_failures => true)
   end
 
-  describe package(packagename) do
-    it { should be_installed }
+  Array(packagename).each do |package|
+    describe package(package) do
+      it { should be_installed }
+    end
   end
 end
