@@ -14,16 +14,29 @@ when 'Linux'
   end
 when 'AIX'
   packagename = 'bos.net.tcp.client'
+when 'Solaris'
+  case fact('operatingsystemrelease')
+  when '5.10'
+    packagename = ['SUNWntpr','SUNWntpu']
+  when '5.11'
+    packagename = 'service/network/ntp'
+  end
 else
   packagename = 'ntp'
 end
 
+if (fact('osfamily') == 'Solaris')
+  config = '/etc/inet/ntp.conf'
+else
+  config = '/etc/ntp.conf'
+end
+
 describe "ntp class:", :unless => UNSUPPORTED_PLATFORMS.include?(fact('osfamily')) do
   it 'applies successfully' do
     pp = "class { 'ntp': }"
 
     apply_manifest(pp, :catch_failures => true) do |r|
-      expect(r.stderr).to eq("")
+      expect(r.stderr).not_to match(/error/i)
     end
   end
 
@@ -60,9 +73,9 @@ describe "ntp class:", :unless => UNSUPPORTED_PLATFORMS.include?(fact('osfamily'
       apply_manifest(pp, :catch_failures => true)
     end
 
-    describe file('/etc/ntp.conf') do
+    describe file("#{config}") do
       it { should be_file }
-      it { should contain 'testcontent' }
+      its(:content) { should match 'testcontent' }
     end
   end
 
@@ -72,9 +85,9 @@ describe "ntp class:", :unless => UNSUPPORTED_PLATFORMS.include?(fact('osfamily'
       apply_manifest(pp, :catch_failures => true)
     end
 
-    describe file('/etc/ntp.conf') do
+    describe file("#{config}") do
       it { should be_file }
-      it { should contain 'driftfile /tmp/driftfile' }
+      its(:content) { should match 'driftfile /tmp/driftfile' }
     end
   end
 
@@ -95,12 +108,12 @@ describe "ntp class:", :unless => UNSUPPORTED_PLATFORMS.include?(fact('osfamily'
       apply_manifest(pp, :catch_failures => true)
     end
 
-    describe file('/etc/ntp.conf') do
+    describe file("#{config}") do
       it { should be_file }
-      it { should contain 'keys /etc/ntp/keys' }
-      it { should contain 'controlkey /etc/ntp/controlkey' }
-      it { should contain 'requestkey 1' }
-      it { should contain 'trustedkey 1 2' }
+      its(:content) { should match 'keys /etc/ntp/keys' }
+      its(:content) { should match 'controlkey /etc/ntp/controlkey' }
+      its(:content) { should match 'requestkey 1' }
+      its(:content) { should match 'trustedkey 1 2' }
     end
   end
 
@@ -109,14 +122,16 @@ describe "ntp class:", :unless => UNSUPPORTED_PLATFORMS.include?(fact('osfamily'
       pp = <<-EOS
       class { 'ntp':
         package_ensure => present,
-        package_name   => ['#{packagename}'],
+        package_name   => #{Array(packagename).inspect},
       }
       EOS
       apply_manifest(pp, :catch_failures => true)
     end
 
-    describe package(packagename) do
-      it { should be_installed }
+    Array(packagename).each do |package|
+      describe package(package) do
+        it { should be_installed }
+      end
     end
   end
 
@@ -130,8 +145,8 @@ describe "ntp class:", :unless => UNSUPPORTED_PLATFORMS.include?(fact('osfamily'
       apply_manifest(pp, :catch_failures => true)
     end
 
-    describe file('/etc/ntp.conf') do
-      it { should contain 'tinker panic' }
+    describe file("#{config}") do
+      its(:content) { should match 'tinker panic' }
     end
   end
 
@@ -145,8 +160,8 @@ describe "ntp class:", :unless => UNSUPPORTED_PLATFORMS.include?(fact('osfamily'
       apply_manifest(pp, :catch_failures => true)
     end
 
-    describe file('/etc/ntp.conf') do
-      it { should_not contain 'tinker panic 0' }
+    describe file("#{config}") do
+      its(:content) { should_not match 'tinker panic 0' }
     end
   end
 
@@ -156,9 +171,9 @@ describe "ntp class:", :unless => UNSUPPORTED_PLATFORMS.include?(fact('osfamily'
       apply_manifest(pp, :catch_failures => true)
     end
 
-    describe file('/etc/ntp.conf') do
+    describe file("#{config}") do
       it { should be_file }
-      it { should contain '127.127.1.0' }
+      its(:content) { should match '127.127.1.0' }
     end
   end
 
